//*******************************************************
//
//	ATtiny13	Software I2C(TWI)
//
//	2020.8.22	KAWAKAMI Yukio
//*******************************************************

#include "main.h"
#include "i2c.h"

//************************************************************
//	TWI 開始条件
//************************************************************
void TWI_start(void){

	SDA_H;
	SCL_H;
	SDA_L;
}


//************************************************************
//	TWI 8bit 送信
//************************************************************
void TWI_send(uchar data){
	char	bit;

	SCL_L;
	for (bit = 0; bit < 8; bit++){
		if (data & 0x80){
			SDA_H;
		} else {
			SDA_L;
		}
		SCL_H;
		WAIT_SCL_H;		// SCL=Hになるまで待つ
		data <<= 1;
		SCL_L;
	}

	SDA_H;
	SCL_L;

	// ACK受信 内容は無視
	SCL_H;
	SCL_L;
}


//************************************************************
//	TWI 8bit 受信
//************************************************************
uchar TWI_recv(uchar nack){
	char	bit;
	uchar	data;

	SDA_H;
	SCL_L;

	data = 0;
	for (bit = 0; bit < 8; bit++){
		SCL_H;
		WAIT_SCL_H;		// SCL=Hになるまで待つ
		data <<= 1;
		if (PINB & (1<<SDA)){
			data |= 1;
		}
		SCL_L;
	}

	// ACK/NACK 送信
	if (nack){
		SCL_L;
		SCL_H;
		SDA_H;
	} else {
		SDA_L;
		SCL_L;
		SCL_H;
	}

	SCL_L;
	SDA_H;

	return data;
}


//************************************************************
//	TWI 停止条件
//************************************************************
void TWI_stop(void){

	SDA_L;
	SCL_H;
	SDA_H;
}

