//*******************************************************
//
//	VFO-10
//
//	MCU : ATtiny13
//		hfuse:FBh	BOD 2.7V
//		lfuse:31h	4.8MHz
//
//	2020.8.23	KAWAKAMI Yukio
//*******************************************************

#include "main.h"
#include "i2c.h"
#include "Si5351.h"


//*******************************************************
//	タイマー0 比較一致A割り込み
//*******************************************************
ISR(TIM0_COMPA_vect){

	// 何もしない。SLEEPの解除のみ
}


//*******************************************************
//	メインルーチン
//*******************************************************
int main(void){
	int16_t	adc, last_adc = 0;
	uint8_t	mode, last_mode = 9;

	//cli();

	//CLKPR = (1<<CLKPCE);	// クロックプリスケーラ変更
	//CLKPR = (1<<CLKPS0);	// 1/2 9.6MHz / 2 = 4.8MHz

	PORTB = (1<<PTT);
	DDRB = 0;

	MCUCR = (1<<SE);		// スリープ許可、アイドリングモード

	TCCR0A = (1<<WGM01);				// CTC
	TCCR0B = (1<<CS02);					// プリスケーラ 1/256
	OCR0A = ((F_CPU/256 + 50)/100 - 1);	// 100Hz
	TIMSK0 = (1<<OCIE0A);				// 比較一致A割り込み許可

	ACSR |= (1<<ACD);	// アナログコンパレータ禁止

	ADMUX = (1<<MUX1);	// ADC2 in,	Ref=Vcc

	sei();

	init_Si5351();

	for(;;){

		//WDR;
		SLEEP;

		// VR読み込み
		ADCSRA = (1<<ADEN)|(1<<ADPS2)|(1<<ADPS1);		// ADC CK/64
		ADCSRA |= (1<<ADSC);							// ADC開始
		while(!(ADCSRA & (1<<ADIF)));
		adc = (int16_t)ADCW;

		// PTT読み込み
		if (PINB & (1<<PTT)){
			mode = MODE_RX;
		} else {
			mode = MODE_TX;
		}

		if (mode != last_mode){
			last_adc = 9999;
			last_mode = mode;
		}
		if (abs(adc - last_adc) >= 8){
			uint8_t	ch;
			ch = (adc + 16) / 32;	// ADC:0〜1023 → ch:0〜32
			set_ch_freq(mode, ch);
			last_adc = adc;
		}
	}
}


